==> hashikake-0.3.0.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/app/view/BoardScroller.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		BoardScroller.java
//	DATE:		2003.5.27
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.app.view;

import java.awt.Rectangle;
import java.awt.ScrollPane;

import java.awt.event.AdjustmentEvent;

import jp.gr.java_conf.ktz.puzzle.hashikake.view.BoardContainer;
import jp.gr.java_conf.ktz.puzzle.hashikake.view.BoardView;

import jp.gr.java_conf.ktz.puzzle.hashikake.command.PieceSizeCommand;
import jp.gr.java_conf.ktz.puzzle.hashikake.command.BoardSizeCommand;

import jp.gr.java_conf.ktz.puzzle.hashikake.util.Command;

/**
 *	scrolltbNViewKw
 */
class BoardScroller extends BoardContainer {
	/**
	 *	RXgN^
	 *
	 *	@param	inContainer	wrapawt component
	 */
	BoardScroller(java.awt.Container inContainer) {
		super(inContainer);
	}
	
	/**
	 *	̔Ֆʂ̏s
	 */
	protected void initializeSelf() {

		Board aBoard = new Board();
		addBoard(aBoard);
	}
	
	/**
	 *	Command̎
	 *
	 *	@param	inCommand	Command
	 */
	protected void processCommandImpl(Command inCommand) {
		final Class aClass = inCommand.getClass();
		
		if (aClass == PieceSizeCommand.class) {
			final int aSize = ((PieceSizeCommand)inCommand).getPieceSize();
			setPieceSize(aSize);
			inCommand.consume();
		}
		else if (aClass == BoardSizeCommand.class) {
			final int aWidth = ((BoardSizeCommand)inCommand).getWidth();
			final int aHeight = ((BoardSizeCommand)inCommand).getHeight();
			setComponentSize(aWidth, aHeight);
		}
	}
	
	/**
	 *	Boardɑ΂Ă1s[X̃TCYZbg
	 *
	 *	@param	inSize ZTCY
	 */
	protected int setPieceSize(final int inSize) {
		// Scroller̃XN[ʂύX
		
		ScrollPane aPane = (ScrollPane)getComponent();
		
		aPane.getHAdjustable().setUnitIncrement(inSize);
		aPane.getVAdjustable().setUnitIncrement(inSize);
		
		return inSize;
	}
	
	/**
	 *	R|[lg̃TCYύX
	 *	ƂēnĺAsubcomponent̃TCYłB
	 *	
	 *	@param	inWidth		subcomponent̕
	 *	@param	inHeight	subcomponent̍
	 *	@return	component̃TCY
	 */
	protected void setComponentSize(final int inWidth, final int inHeight) {
		ScrollPane aPane = (ScrollPane)getComponent();
		final int aHHeight = aPane.getHScrollbarHeight();
		final int aVWidth = aPane.getVScrollbarWidth();
		
		int aWidth = inWidth + aVWidth;
		int aHeight = inHeight + aHHeight;
		aPane.invalidate();		
		aPane.setSize(aWidth, aHeight);
	}
}

==> hashikake-0.3.3.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/app/view/BoardScroller.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		BoardScroller.java
//	DATE:		2003.5.27
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.app.view;

import java.awt.Rectangle;
import java.awt.ScrollPane;

import java.awt.event.AdjustmentEvent;

import jp.gr.java_conf.ktz.puzzle.hashikake.view.BoardContainer;
import jp.gr.java_conf.ktz.puzzle.hashikake.view.BoardView;

import jp.gr.java_conf.ktz.puzzle.hashikake.command.PieceSizeCommand;
import jp.gr.java_conf.ktz.puzzle.hashikake.command.BoardSizeCommand;

import jp.gr.java_conf.ktz.puzzle.hashikake.util.Command;

/**
 *	scrolltbNViewKw
 */
class BoardScroller extends BoardContainer {
	/**
	 *	RXgN^
	 *
	 *	@param	inContainer	wrapawt component
	 */
	BoardScroller(java.awt.Container inContainer) {
		super(inContainer);
	}
	
	/**
	 *	̔Ֆʂ̏s
	 */
	protected void initializeSelf() {

		Board aBoard = new Board();
		addBoard(aBoard);
	}
	
	/**
	 *	Command̎
	 *
	 *	@param	inCommand	Command
	 */
	protected void processCommandImpl(Command inCommand) {
		final Class aClass = inCommand.getClass();
		
		if (aClass == PieceSizeCommand.class) {
			final int aSize = ((PieceSizeCommand)inCommand).getPieceSize();
			setPieceSize(aSize);
			inCommand.consume();
		}
		else if (aClass == BoardSizeCommand.class) {
			final int aWidth = ((BoardSizeCommand)inCommand).getComponentWidth();
			final int aHeight = ((BoardSizeCommand)inCommand).getComponentHeight();
			setComponentSize(aWidth, aHeight);
		}
	}
	
	/**
	 *	Boardɑ΂Ă1s[X̃TCYZbg
	 *
	 *	@param	inSize ZTCY
	 */
	protected int setPieceSize(final int inSize) {
		// Scroller̃XN[ʂύX
		
		ScrollPane aPane = (ScrollPane)getComponent();
		
		aPane.getHAdjustable().setUnitIncrement(inSize);
		aPane.getVAdjustable().setUnitIncrement(inSize);
		
		return inSize;
	}
	
	private void setComponentSize(final int inWidth, final int inHeight) {
		ScrollPane aPane = (ScrollPane)getComponent();
		final int aWidth = inWidth + aPane.getHScrollbarHeight();
		final int aHeight = inHeight + aPane.getVScrollbarWidth();
		
		aPane.invalidate();		
		aPane.setSize(aWidth, aHeight);
	}
}
